# ts-task-script-utils <!-- omit in toc -->

[![Build Status](https://travis-ci.com/tetrascience/ts-task-script-utils.svg?branch=master)](https://travis-ci.com/tetrascience/ts-task-script-utils)

Utility functions for Tetra Task Scripts

- [Installation](#installation)
- [Test](#test)

## Installation

`pip install ts-task-script-utils`

## Test

`pipenv install --dev`
then
`pipenv run python -m pytest`
